Geometry
========

.. autoclass:: pancad.geometry.AbstractGeometry
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Circle
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.CoordinateSystem
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Ellipse
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Line
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.LineSegment
    :show-inheritance:
    :members:

.. autoclass:: pancad.geometry.Point
    :show-inheritance:
    :members:

Enumerations
------------

.. autoclass:: pancad.geometry.constants.ConstraintReference
    :show-inheritance:
    :members:
